@@ -1,10 +1,10 @@
 import pandas as pd
 from thetadata import DataType
-from .end_of_day import end_of_day
+from end_of_day_stk import end_of_day
 
 
 def main():
-    # get the data from the previous example
+    # get the data from the previous EOD stock data example
     data: pd.DataFrame = end_of_day()
 
     # print all datatypes in the response
@@ -13,9 +13,9 @@ def main():
     # get the first row in the DataFrame (our requested data)
     row = data.iloc[0]
 
-    # print just the close price
-    close_price = row[DataType.CLOSE]
-    print(f"{close_price=}")
+    # print just the open price
+    open_price = row[DataType.OPEN]
+    print(f"{open_price=}")
 
 
 if __name__ == "__main__":
