@@ -1,9 +1,9 @@
 """Contains tests for the tutorial section of the documentation."""
 import pytest
 import docs
-from docs.get_last import get_last
-from docs.list_roots import get_roots
-from docs.end_of_day import end_of_day
+from docs.get_last_opt import get_last
+from docs.list_roots_opt import get_roots
+from docs.end_of_day_opt import end_of_day
 from docs import manipulate_df, manipulate_series
 
 @pytest.mark.skip(reason="No data for contract")
